@@ -47,7 +47,7 @@ describe 'ironic::client' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :client_package => 'python3-ironicclient' }
         when 'RedHat'
