@@ -41,6 +41,7 @@ describe 'ironic::drivers::inspector' do
       is_expected.to contain_ironic_config('inspector/password').with_value('<SERVICE DEFAULT>').with_secret(true)
       is_expected.to contain_ironic_config('inspector/user_domain_name').with_value('Default')
       is_expected.to contain_ironic_config('inspector/project_domain_name').with_value('Default')
+      is_expected.to contain_ironic_config('inspector/system_scope').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('inspector/region_name').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('inspector/endpoint_override').with_value('<SERVICE DEFAULT>')
     end
@@ -48,18 +49,18 @@ describe 'ironic::drivers::inspector' do
     context 'when overriding parameters' do
       before :each do
         params.merge!(
-            :auth_type                  => 'noauth',
-            :auth_url                   => 'http://example.com',
-            :project_name               => 'project1',
-            :username                   => 'admin',
-            :password                   => 'pa$$w0rd',
-            :user_domain_name           => 'NonDefault',
-            :project_domain_name        => 'NonDefault',
-            :region_name                => 'regionTwo',
-            :endpoint_override          => 'http://example2.com',
-            :callback_endpoint_override => 'http://10.0.0.1/v1/continue',
-            :power_off                  => false,
-            :extra_kernel_params        => 'ipa-inspection-collectors=a,b,c',
+          :auth_type                  => 'noauth',
+          :auth_url                   => 'http://example.com',
+          :project_name               => 'project1',
+          :username                   => 'admin',
+          :password                   => 'pa$$w0rd',
+          :user_domain_name           => 'NonDefault',
+          :project_domain_name        => 'NonDefault',
+          :region_name                => 'regionTwo',
+          :endpoint_override          => 'http://example2.com',
+          :callback_endpoint_override => 'http://10.0.0.1/v1/continue',
+          :power_off                  => false,
+          :extra_kernel_params        => 'ipa-inspection-collectors=a,b,c',
         )
       end
 
@@ -71,6 +72,7 @@ describe 'ironic::drivers::inspector' do
         is_expected.to contain_ironic_config('inspector/password').with_value(p[:password]).with_secret(true)
         is_expected.to contain_ironic_config('inspector/user_domain_name').with_value(p[:user_domain_name])
         is_expected.to contain_ironic_config('inspector/project_domain_name').with_value(p[:project_domain_name])
+        is_expected.to contain_ironic_config('inspector/system_scope').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_ironic_config('inspector/region_name').with_value(p[:region_name])
         is_expected.to contain_ironic_config('inspector/endpoint_override').with_value(p[:endpoint_override])
         is_expected.to contain_ironic_config('inspector/callback_endpoint_override').with_value(p[:callback_endpoint_override])
@@ -79,6 +81,19 @@ describe 'ironic::drivers::inspector' do
       end
     end
 
+    context 'when system_scope is set' do
+      before :each do
+        params.merge!(
+          :system_scope => 'all'
+        )
+      end
+
+      it 'configures system-scoped credential' do
+        is_expected.to contain_ironic_config('inspector/project_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_ironic_config('inspector/project_domain_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_ironic_config('inspector/system_scope').with_value('all')
+      end
+    end
   end
 
   on_supported_os({
