@@ -41,6 +41,7 @@ describe 'ironic::neutron' do
       is_expected.to contain_ironic_config('neutron/password').with_value('<SERVICE DEFAULT>').with_secret(true)
       is_expected.to contain_ironic_config('neutron/user_domain_name').with_value('Default')
       is_expected.to contain_ironic_config('neutron/project_domain_name').with_value('Default')
+      is_expected.to contain_ironic_config('neutron/system_scope').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('neutron/region_name').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('neutron/endpoint_override').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('neutron/dhcpv6_stateful_address_count').with_value('<SERVICE DEFAULT>')
@@ -49,16 +50,16 @@ describe 'ironic::neutron' do
     context 'when overriding parameters' do
       before :each do
         params.merge!(
-            :auth_type                     => 'noauth',
-            :auth_url                      => 'http://example.com',
-            :project_name                  => 'project1',
-            :username                      => 'admin',
-            :password                      => 'pa$$w0rd',
-            :user_domain_name              => 'NonDefault',
-            :project_domain_name           => 'NonDefault',
-            :region_name                   => 'regionTwo',
-            :endpoint_override             => 'http://example2.com',
-            :dhcpv6_stateful_address_count => 8,
+          :auth_type                     => 'noauth',
+          :auth_url                      => 'http://example.com',
+          :project_name                  => 'project1',
+          :username                      => 'admin',
+          :password                      => 'pa$$w0rd',
+          :user_domain_name              => 'NonDefault',
+          :project_domain_name           => 'NonDefault',
+          :region_name                   => 'regionTwo',
+          :endpoint_override             => 'http://example2.com',
+          :dhcpv6_stateful_address_count => 8,
         )
       end
 
@@ -70,12 +71,25 @@ describe 'ironic::neutron' do
         is_expected.to contain_ironic_config('neutron/password').with_value(p[:password]).with_secret(true)
         is_expected.to contain_ironic_config('neutron/user_domain_name').with_value(p[:user_domain_name])
         is_expected.to contain_ironic_config('neutron/project_domain_name').with_value(p[:project_domain_name])
+        is_expected.to contain_ironic_config('neutron/system_scope').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_ironic_config('neutron/region_name').with_value(p[:region_name])
         is_expected.to contain_ironic_config('neutron/endpoint_override').with_value(p[:endpoint_override])
         is_expected.to contain_ironic_config('neutron/dhcpv6_stateful_address_count').with_value(p[:dhcpv6_stateful_address_count])
       end
     end
 
+    context 'when system_scope is set' do
+      before do
+        params.merge!(
+          :system_scope => 'all'
+        )
+      end
+      it 'configures system-scoped credential' do
+        is_expected.to contain_ironic_config('neutron/project_domain_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_ironic_config('neutron/project_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_ironic_config('neutron/system_scope').with_value('all')
+      end
+    end
   end
 
   on_supported_os({
