@@ -10,7 +10,7 @@ describe 'ironic::wsgi::apache' do
         :group                       => 'ironic',
         :path                        => '/',
         :priority                    => 10,
-        :servername                  => facts[:fqdn],
+        :servername                  => 'foo.example.com',
         :ssl                         => false,
         :threads                     => 15,
         :user                        => 'ironic',
@@ -147,14 +147,12 @@ describe 'ironic::wsgi::apache' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :os_workers     => 8,
-          :concat_basedir => '/var/lib/puppet/concat',
-          :fqdn           => 'some.host.tld'
+          :os_workers => 8,
         }))
       end
 
       let :platform_params do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
             {
               :wsgi_script_path   => '/usr/lib/cgi-bin/ironic',
